==> drools-pmml-6.2.0.Final-redhat-9-sources.jar: org/dmg/pmml/pmml_4_2/descr/PMML.java <==

package org.dmg.pmml.pmml_4_2.descr;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Header"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}MiningBuildTask" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}DataDictionary"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}TransformationDictionary" minOccurs="0"/>
 *         &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *           &lt;group ref="{http://www.dmg.org/PMML-4_2}MODEL-ELEMENT"/>
 *         &lt;/sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="version" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "header",
    "miningBuildTask",
    "dataDictionary",
    "transformationDictionary",
    "associationModelsAndBaselineModelsAndClusteringModels",
    "extensions"
})
@XmlRootElement(name = "PMML")
public class PMML
    implements Serializable
{

    private final static long serialVersionUID = 145235L;
    @XmlElement(name = "Header", required = true)
    protected Header header;
    @XmlElement(name = "MiningBuildTask")
    protected MiningBuildTask miningBuildTask;
    @XmlElement(name = "DataDictionary", required = true)
    protected DataDictionary dataDictionary;
    @XmlElement(name = "TransformationDictionary")
    protected TransformationDictionary transformationDictionary;
    @XmlElements({
        @XmlElement(name = "GeneralRegressionModel", type = GeneralRegressionModel.class),
        @XmlElement(name = "NaiveBayesModel", type = NaiveBayesModel.class),
        @XmlElement(name = "RegressionModel", type = RegressionModel.class),
        @XmlElement(name = "TextModel", type = TextModel.class),
        @XmlElement(name = "SupportVectorMachineModel", type = SupportVectorMachineModel.class),
        @XmlElement(name = "MiningModel", type = MiningModel.class),
        @XmlElement(name = "TreeModel", type = TreeModel.class),
        @XmlElement(name = "AssociationModel", type = AssociationModel.class),
        @XmlElement(name = "TimeSeriesModel", type = TimeSeriesModel.class),
        @XmlElement(name = "NeuralNetwork", type = NeuralNetwork.class),
        @XmlElement(name = "Scorecard", type = Scorecard.class),
        @XmlElement(name = "SequenceModel", type = SequenceModel.class),
        @XmlElement(name = "BaselineModel", type = BaselineModel.class),
        @XmlElement(name = "RuleSetModel", type = RuleSetModel.class),
        @XmlElement(name = "ClusteringModel", type = ClusteringModel.class),
        @XmlElement(name = "NearestNeighborModel", type = NearestNeighborModel.class)
    })
    protected List<Serializable> associationModelsAndBaselineModelsAndClusteringModels;
    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "version", required = true)
    protected String version;

    /**
     * Gets the value of the header property.
     * 
     * @return
     *     possible object is
     *     {@link Header }
     *     
     */
    public Header getHeader() {
        return header;
    }

    /**
     * Sets the value of the header property.
     * 
     * @param value
     *     allowed object is
     *     {@link Header }
     *     
     */
    public void setHeader(Header value) {
        this.header = value;
    }

    /**
     * Gets the value of the miningBuildTask property.
     * 
     * @return
     *     possible object is
     *     {@link MiningBuildTask }
     *     
     */
    public MiningBuildTask getMiningBuildTask() {
        return miningBuildTask;
    }

    /**
     * Sets the value of the miningBuildTask property.
     * 
     * @param value
     *     allowed object is
     *     {@link MiningBuildTask }
     *     
     */
    public void setMiningBuildTask(MiningBuildTask value) {
        this.miningBuildTask = value;
    }

    /**
     * Gets the value of the dataDictionary property.
     * 
     * @return
     *     possible object is
     *     {@link DataDictionary }
     *     
     */
    public DataDictionary getDataDictionary() {
        return dataDictionary;
    }

    /**
     * Sets the value of the dataDictionary property.
     * 
     * @param value
     *     allowed object is
     *     {@link DataDictionary }
     *     
     */
    public void setDataDictionary(DataDictionary value) {
        this.dataDictionary = value;
    }

    /**
     * Gets the value of the transformationDictionary property.
     * 
     * @return
     *     possible object is
     *     {@link TransformationDictionary }
     *     
     */
    public TransformationDictionary getTransformationDictionary() {
        return transformationDictionary;
    }

    /**
     * Sets the value of the transformationDictionary property.
     * 
     * @param value
     *     allowed object is
     *     {@link TransformationDictionary }
     *     
     */
    public void setTransformationDictionary(TransformationDictionary value) {
        this.transformationDictionary = value;
    }

    /**
     * Gets the value of the associationModelsAndBaselineModelsAndClusteringModels property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the associationModelsAndBaselineModelsAndClusteringModels property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAssociationModelsAndBaselineModelsAndClusteringModels().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link GeneralRegressionModel }
     * {@link NaiveBayesModel }
     * {@link RegressionModel }
     * {@link TextModel }
     * {@link SupportVectorMachineModel }
     * {@link MiningModel }
     * {@link TreeModel }
     * {@link AssociationModel }
     * {@link TimeSeriesModel }
     * {@link NeuralNetwork }
     * {@link Scorecard }
     * {@link SequenceModel }
     * {@link BaselineModel }
     * {@link RuleSetModel }
     * {@link ClusteringModel }
     * {@link NearestNeighborModel }
     * 
     * 
     */
    public List<Serializable> getAssociationModelsAndBaselineModelsAndClusteringModels() {
        if (associationModelsAndBaselineModelsAndClusteringModels == null) {
            associationModelsAndBaselineModelsAndClusteringModels = new ArrayList<Serializable>();
        }
        return this.associationModelsAndBaselineModelsAndClusteringModels;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        return version;
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> drools-pmml-6.3.0.Final-redhat-9-sources.jar: org/dmg/pmml/pmml_4_2/descr/PMML.java <==

package org.dmg.pmml.pmml_4_2.descr;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Header"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}MiningBuildTask" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}DataDictionary"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}TransformationDictionary" minOccurs="0"/>
 *         &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *           &lt;group ref="{http://www.dmg.org/PMML-4_2}MODEL-ELEMENT"/>
 *         &lt;/sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="version" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "header",
    "miningBuildTask",
    "dataDictionary",
    "transformationDictionary",
    "associationModelsAndBaselineModelsAndClusteringModels",
    "extensions"
})
@XmlRootElement(name = "PMML")
public class PMML
    implements Serializable
{

    private final static long serialVersionUID = 145235L;
    @XmlElement(name = "Header", required = true)
    protected Header header;
    @XmlElement(name = "MiningBuildTask")
    protected MiningBuildTask miningBuildTask;
    @XmlElement(name = "DataDictionary", required = true)
    protected DataDictionary dataDictionary;
    @XmlElement(name = "TransformationDictionary")
    protected TransformationDictionary transformationDictionary;
    @XmlElements({
        @XmlElement(name = "TimeSeriesModel", type = TimeSeriesModel.class),
        @XmlElement(name = "SupportVectorMachineModel", type = SupportVectorMachineModel.class),
        @XmlElement(name = "AssociationModel", type = AssociationModel.class),
        @XmlElement(name = "GeneralRegressionModel", type = GeneralRegressionModel.class),
        @XmlElement(name = "Scorecard", type = Scorecard.class),
        @XmlElement(name = "ClusteringModel", type = ClusteringModel.class),
        @XmlElement(name = "RuleSetModel", type = RuleSetModel.class),
        @XmlElement(name = "BaselineModel", type = BaselineModel.class),
        @XmlElement(name = "MiningModel", type = MiningModel.class),
        @XmlElement(name = "TextModel", type = TextModel.class),
        @XmlElement(name = "NearestNeighborModel", type = NearestNeighborModel.class),
        @XmlElement(name = "RegressionModel", type = RegressionModel.class),
        @XmlElement(name = "TreeModel", type = TreeModel.class),
        @XmlElement(name = "NeuralNetwork", type = NeuralNetwork.class),
        @XmlElement(name = "SequenceModel", type = SequenceModel.class),
        @XmlElement(name = "NaiveBayesModel", type = NaiveBayesModel.class)
    })
    protected List<Serializable> associationModelsAndBaselineModelsAndClusteringModels;
    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "version", required = true)
    protected String version;

    /**
     * Gets the value of the header property.
     * 
     * @return
     *     possible object is
     *     {@link Header }
     *     
     */
    public Header getHeader() {
        return header;
    }

    /**
     * Sets the value of the header property.
     * 
     * @param value
     *     allowed object is
     *     {@link Header }
     *     
     */
    public void setHeader(Header value) {
        this.header = value;
    }

    /**
     * Gets the value of the miningBuildTask property.
     * 
     * @return
     *     possible object is
     *     {@link MiningBuildTask }
     *     
     */
    public MiningBuildTask getMiningBuildTask() {
        return miningBuildTask;
    }

    /**
     * Sets the value of the miningBuildTask property.
     * 
     * @param value
     *     allowed object is
     *     {@link MiningBuildTask }
     *     
     */
    public void setMiningBuildTask(MiningBuildTask value) {
        this.miningBuildTask = value;
    }

    /**
     * Gets the value of the dataDictionary property.
     * 
     * @return
     *     possible object is
     *     {@link DataDictionary }
     *     
     */
    public DataDictionary getDataDictionary() {
        return dataDictionary;
    }

    /**
     * Sets the value of the dataDictionary property.
     * 
     * @param value
     *     allowed object is
     *     {@link DataDictionary }
     *     
     */
    public void setDataDictionary(DataDictionary value) {
        this.dataDictionary = value;
    }

    /**
     * Gets the value of the transformationDictionary property.
     * 
     * @return
     *     possible object is
     *     {@link TransformationDictionary }
     *     
     */
    public TransformationDictionary getTransformationDictionary() {
        return transformationDictionary;
    }

    /**
     * Sets the value of the transformationDictionary property.
     * 
     * @param value
     *     allowed object is
     *     {@link TransformationDictionary }
     *     
     */
    public void setTransformationDictionary(TransformationDictionary value) {
        this.transformationDictionary = value;
    }

    /**
     * Gets the value of the associationModelsAndBaselineModelsAndClusteringModels property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the associationModelsAndBaselineModelsAndClusteringModels property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAssociationModelsAndBaselineModelsAndClusteringModels().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeSeriesModel }
     * {@link SupportVectorMachineModel }
     * {@link AssociationModel }
     * {@link GeneralRegressionModel }
     * {@link Scorecard }
     * {@link ClusteringModel }
     * {@link RuleSetModel }
     * {@link BaselineModel }
     * {@link MiningModel }
     * {@link TextModel }
     * {@link NearestNeighborModel }
     * {@link RegressionModel }
     * {@link TreeModel }
     * {@link NeuralNetwork }
     * {@link SequenceModel }
     * {@link NaiveBayesModel }
     * 
     * 
     */
    public List<Serializable> getAssociationModelsAndBaselineModelsAndClusteringModels() {
        if (associationModelsAndBaselineModelsAndClusteringModels == null) {
            associationModelsAndBaselineModelsAndClusteringModels = new ArrayList<Serializable>();
        }
        return this.associationModelsAndBaselineModelsAndClusteringModels;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        return version;
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
